PostgreSQL

Struct PostgreSQL 

pub struct PostgreSQL { /* private fields */ }
PostgreSQL server

Implementations

Source

impl PostgreSQL

PostgreSQL server methods

pub fn new(settings: Settings) -> Self

Create a new crate::postgresql::PostgreSQL instance

pub fn status(&self) -> Status

Get the status of the PostgreSQL server

pub fn settings(&self) -> &Settings

Get the settings of the PostgreSQL server

pub fn setup(&mut self) -> Result<()>

Set up the database by extracting the archive and initializing the database. If the installation directory already exists, the archive will not be extracted. If the data directory already exists, the database will not be initialized.

Errors

Returns an error if the setup fails.

pub fn start(&mut self) -> Result<()>

Start the database and wait for the startup to complete. If the port is set to 0, the database will be started on a random port.

Errors

Returns an error if the startup fails.

pub fn stop(&self) -> Result<()>

Stop the database gracefully (smart mode) and wait for the shutdown to complete.

Errors

Returns an error if the shutdown fails.

pub fn create_database<S>(&self, database_name: S) -> Result<()>
where S: AsRef<str> + Debug,

Create a new database with the given name.

Errors

Returns an error if the database creation fails.

pub fn database_exists<S>(&self, database_name: S) -> Result<bool>
where S: AsRef<str> + Debug,

Check if a database with the given name exists.

Errors

Returns an error if the database existence check fails.

pub fn drop_database<S>(&self, database_name: S) -> Result<()>
where S: AsRef<str> + Debug,

Drop a database with the given name.

Errors

Returns an error if the database drop fails.