pub struct PostgreSQL { /* private fields */ }Expand description
PostgreSQL server
Implementations
Sourceimpl PostgreSQL
PostgreSQL server methods
impl PostgreSQL
PostgreSQL server methods
Sourcepub fn new(settings: Settings) -> Self
pub fn new(settings: Settings) -> Self
Create a new crate::postgresql::PostgreSQL instance
Sourcepub fn setup(&mut self) -> Result<()>
pub fn setup(&mut self) -> Result<()>
Set up the database by extracting the archive and initializing the database. If the installation directory already exists, the archive will not be extracted. If the data directory already exists, the database will not be initialized.
Errors
Returns an error if the setup fails.
Sourcepub fn start(&mut self) -> Result<()>
pub fn start(&mut self) -> Result<()>
Start the database and wait for the startup to complete.
If the port is set to 0, the database will be started on a random port.
Errors
Returns an error if the startup fails.
Sourcepub fn stop(&self) -> Result<()>
pub fn stop(&self) -> Result<()>
Stop the database gracefully (smart mode) and wait for the shutdown to complete.
Errors
Returns an error if the shutdown fails.
Sourcepub fn create_database<S>(&self, database_name: S) -> Result<()>
pub fn create_database<S>(&self, database_name: S) -> Result<()>
Sourcepub fn database_exists<S>(&self, database_name: S) -> Result<bool>
pub fn database_exists<S>(&self, database_name: S) -> Result<bool>
Check if a database with the given name exists.
Errors
Returns an error if the database existence check fails.